@@ -115,6 +115,7 @@ class Script:
         self.eventCache = {}
         self.whereAmI = self.getWhereAmI()
         self.bookmarks = self.getBookmarks()
+        self.spellcheck = self.getSpellCheck()
         self.voices = settings.voices
         self.tutorialGenerator = self.getTutorialGenerator()
 
@@ -228,6 +229,10 @@ class Script:
         """
         return None
 
+    def getSpellCheck(self):
+        """Returns the spellcheck support for this script."""
+        return None
+
     def getUtilities(self):
         """Returns the utilites for this script.
         """
