@@ -95,7 +95,10 @@ class Script(gtk.Script):
         if not event.detail1:
             return
 
-        if event.source.parent == self.spellcheck.getSuggestionsList():
+        if self.spellcheck.isSuggestionsItem(event.source) \
+           and self.spellcheck.isSuggestionsItem(orca_state.locusOfFocus):
+            orca.setLocusOfFocus(event, event.source, False)
+            self.updateBraille(orca_state.locusOfFocus)
             self.spellcheck.presentSuggestionListItem()
             return
 
@@ -108,8 +111,24 @@ class Script(gtk.Script):
             gtk.Script.onNameChanged(self, event)
             return
 
-        if event.source.name == self.spellcheck.getMisspelledWord():
+        name = event.source.name
+        if name == self.spellcheck.getMisspelledWord():
             self.spellcheck.presentErrorDetails()
+            return
+
+        parent = event.source.parent
+        if parent != self.spellcheck.getSuggestionsList() \
+           or not parent.getState().contains(pyatspi.STATE_FOCUSED):
+            return
+
+        entry = self.spellcheck.getChangeToEntry()
+        if name != self.utilities.displayedText(entry):
+            return
+
+        # If we're here, the locusOfFocus was in the selection list when
+        # that list got destroyed and repopulated. Focus is still there.
+        orca.setLocusOfFocus(event, event.source, False)
+        self.updateBraille(orca_state.locusOfFocus)
 
     def onSensitiveChanged(self, event):
         """Callback for object:state-changed:sensitive accessibility events."""
@@ -146,6 +165,7 @@ class Script(gtk.Script):
 
         self.spellcheck.presentErrorDetails()
         orca.setLocusOfFocus(None, self.spellcheck.getChangeToEntry(), False)
+        self.updateBraille(orca_state.locusOfFocus)
 
     def onWindowDeactivated(self, event):
         """Callback for window:deactivate accessibility events."""
